pub struct ResolvedVisitor;Trait Implementations
Sourceimpl Clone for ResolvedVisitor
impl Clone for ResolvedVisitor
Sourcefn clone(&self) -> ResolvedVisitor
fn clone(&self) -> ResolvedVisitor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ResolvedVisitor
Sourceimpl<Block, Passthrough> PrfVisitor<Block, Passthrough> for ResolvedVisitor
Identity visitor that preserves a resolved node’s structural shape.
impl<Block, Passthrough> PrfVisitor<Block, Passthrough> for ResolvedVisitor
Identity visitor that preserves a resolved node’s structural shape.
Backend sequence and map drivers use this visitor to collect child
programs as ResolvedPrf nodes before the caller’s final visitor is
applied.
type Value = ResolvedPrf<Block, Passthrough>
fn visit_block(self, block: Block) -> Result<Self::Value, PrfVisitorError>
fn visit_seq( self, seq: SeqAccess<Block, Passthrough>, ) -> Result<Self::Value, PrfVisitorError>
fn visit_map( self, map: MapAccess<Block, Passthrough>, ) -> Result<Self::Value, PrfVisitorError>
fn visit_absent(self) -> Result<Self::Value, PrfVisitorError>
Sourcefn visit_passthrough(
self,
value: Passthrough,
) -> Result<Self::Value, PrfVisitorError>
fn visit_passthrough( self, value: Passthrough, ) -> Result<Self::Value, PrfVisitorError>
Passthrough is an explicit non-secret channel. It receives no PRF
protection and must not carry keys, plaintexts, or credentials.