pub enum ResolvedPrf<Block, Passthrough> {
Block(Block),
Sequence(Vec<ResolvedPrf<Block, Passthrough>>),
Map(Vec<(String, ResolvedPrf<Block, Passthrough>)>),
Absent,
Passthrough(Passthrough),
}Expand description
A fully resolved node supplied to sequence and map visitors.
Visitors may consume each child with a different visitor, allowing a handwritten record to produce heterogeneous owned output from one batch.
Variants
Block(Block)
Sequence(Vec<ResolvedPrf<Block, Passthrough>>)
Map(Vec<(String, ResolvedPrf<Block, Passthrough>)>)
Absent
Passthrough(Passthrough)
Implementations
Sourceimpl<Block, Passthrough> ResolvedPrf<Block, Passthrough>
impl<Block, Passthrough> ResolvedPrf<Block, Passthrough>
pub fn visit<V>(self, visitor: V) -> Result<V::Value, PrfVisitorError>where
V: PrfVisitor<Block, Passthrough>,